@@ -71,3 +71,7 @@ elif sys.version_info[0]>=3:
 		bool: 'boolean',
 		float: 'float'
 	}
+
+def portable_string(instr,encoding):
+	return instr if type(instr)==PORTABLE_STRING else PORTABLE_STRING(instr,encoding)
+	
\ No newline at end of file
