@@ -122,14 +122,15 @@ class PySiteApplication(object):
 			output = ""
 			
 			content_len = environ.get('CONTENT_LENGTH')
-			post_data = ''
-			if content_len:
-				post_data = environ['wsgi.input'].read(int(content_len))
+			form_data = ''
+			if content_len and environ.get('CONTENT_TYPE',None)=='application/x-www-form-urlencoded':
+				# We have form-encoded post data
+				form_data = environ['wsgi.input'].read(int(content_len))
 			query_string = environ['QUERY_STRING']
 			cookies = ''
 			if 'HTTP_COOKIE' in environ:
 				cookies = environ['HTTP_COOKIE']
-			req_data = HTTPRequestData(post_data,query_string,cookies)
+			req_data = HTTPRequestData(form_data,query_string,cookies)
 			
 			path = environ['PATH_INFO'][1:]
 			# Static files
